<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
 
function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {
	
	// Color schemes
	$color_scheme = array("red" => __('Red', 'twentyfourteen'), "green" => __('Green', 'twentyfourteen'), "blue" => __('Blue', 'twentyfourteen'), "sandy" =>__('Sandy', 'twentyfourteen'), "yellow" =>__('Yellow', 'twentyfourteen'),  "cherry" =>__('Cherry', 'twentyfourteen'),  "orange" =>__('Orange', 'twentyfourteen'));

	$radio = array("0" => __('No', 'twentyfourteen'),"1" => __('Yes', 'twentyfourteen'));

	// Pull all the categories into an array
	$options_categories = array();  
    $args = array();
	$options_categories_obj = get_categories( );

	foreach ($options_categories_obj as $category) {
    	$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all the pages into an array
	$options_pages = array();  
	$options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
    	$options_pages[$page->ID] = $page->post_title;
	}
		
	// If using image radio buttons, define a directory path
	$imagepath =  get_stylesheet_directory_uri() . '/images/';
		
	$options = array();
	$options[] = array( "name" => __('Social Icon settings', 'twentyfourteen'),
						"type" => "heading");	
	$options[] = array( "name" => __('Add Facebook icon', 'twentyfourteen'),
	"desc" => __('Add facebook link'),
	"id" => "facebook_icon",
	"type" => "text");
	
	$options[] = array( "name" => __('Add Twitter icon', 'twentyfourteen'),
	"desc" => __('Add Twitter link'),
	"id" => "twitter_icon",
	"type" => "text");
	
	$options[] = array( "name" => __('Add Youtube icon', 'twentyfourteen'),
	"desc" => __('Add Youtube link'),
	"id" => "youtube_icon",
	"type" => "text");
	
	$options[] = array( "name" => __('Add Google icon', 'twentyfourteen'),
	"desc" => __('Add Google+ link'),
	"id" => "google_icon",
	"type" => "text");
	
	
	$options[] = array( "name" => __('Add pinterest icon', 'twentyfourteen'),
	"desc" => __('Add pinterest link'),
	"id" => "pinterest_icon",
	"type" => "text");
						
	$options[] = array( "name" => __('Home settings', 'twentyfourteen'),
						"type" => "heading");					

	$options[] = array( "name" => __('Add logo image', 'twentyfourteen'),
						"desc" => __('You can upload custom image for your website logo (optional).', 'twentyfourteen'),
						"id" => "header_logo",
						"type" => "upload");
                        
	$options[] = array( "name" => __('Contact number', 'twentyfourteen'),
						"desc" => __('Do you want to display Contact number on  pages?', 'twentyfourteen'),
						"id" => "contact_number",
                        "std" => 0,
						"type" => "text",
                        "class" => "hidden_control"                        
                        );
	$options[] = array( "name" => __('Location', 'twentyfourteen'),
						"desc" => __('Add location here'),
						"id" => "location",
                        "std" => 0,
						"type" => "text",
                        "class" => "hidden_control"                        
                        );
	
	$options[] = array( "name" => __('Add Facebook image', 'twentyfourteen'),
	"desc" => __('You can upload custom image for your website logo (optional).', 'twentyfourteen'),
	"id" => "facebook_image",
	"type" => "upload");
	
       
                        
	$options[] = array( "name" => __('Facebook link', 'twentyfourteen'),
						"desc" => __('Do you want to display link on  pages?', 'twentyfourteen'),
						"id" => "facebook_link",
                        "std" => 0,
						"type" => "text",
                        "class" => "hidden_control"                        
                        );
	$options[] = array( "name" => __('Facebook link', 'twentyfourteen'),
						"desc" => __('Do you want to display link on  pages?', 'twentyfourteen'),
						"id" => "facebook_link",
                        "std" => 0,
						"type" => "text",
                        "class" => "hidden_control"                        
                        );					
						
	$options[] = array( "name" => __('Email', 'Chelmsford Market'),
					"desc" => __('Do you want to display Email pages?', 'twentyfourteen'),
					"id" => "email_id",
					"std" => 0,
					"type" => "text",
					"class" => "hidden_control"                        
					);

                              
	$options[] = array( "name" => __('Footer Setting', 'twentyfourteen'),
						"type" => "heading");							

	$options[] = array( "name" => __('Add Footer Content', 'twentyfourteen'),
						"id" => "Chelmsford_Market_footer",
                        "desc" => __('You can add here footer content'),
						"std" => "default",
						"type" => "text"
						);
   $options[] = array( "name" => __('Fax address', 'twentyfourteen'),
						"desc" => __('Add location here'),
						"id" => "fax_address",
                        "std" => 0,
						"type" => "text",
                        "class" => "hidden_control"
						);
	$options[] = array( "name" => __('Footer address', 'twentyfourteen'),
						"desc" => __('Add Footer here'),
						"id" => "footer_address",
                        "std" => 0,
						"type" => "text",
                        "class" => "hidden_control"
						);
						
	$options[] = array( "name" => __('Footer Logo', 'twentyfourteen'),
						"desc" => __('You can upload footer logo here'),
						"id" => "footer_logo",
						"type" => "upload"
						);
   $options[] = array( "name" => __('Copyright', 'twentyfourteen'),
						"desc" => __('Footer Copyright text'),
						"id" => "footer_copyright",
						"type" => "text"
						);	
						
	$options[] = array( "name" => __('Video settings', 'twentyfourteen'),
						"type" => "heading");
	$options[] = array( "name" => __('Add Video', 'twentyfourteen'),
						"desc" => __('You can upload video.', 'twentyfourteen'),
						"id" => "video",
						"type" => "upload");					
						
						
	$options[] = array( "name" => __('Banner settings', 'twentyfourteen'),
						"type" => "heading");
						
						$options[] = array( "name" => __('Add banner image for map', 'twentyfourteen'),
						"desc" => __('You can upload banner image for your website (optional).', 'twentyfourteen'),
						"id" => "Chelmsford_Market_banner_map",
						"type" => "upload");
						
						
						$options[] = array( "name" => __('Add map image for category page', 'twentyfourteen'),
						"desc" => __('You can upload custom image for your category pages (optional).', 'twentyfourteen'),
						"id" => "Chelmsford_Market_category_image",
						"type" => "upload");

						
						
						$options[] = array( "name" => __('Add banner image for stalls', 'twentyfourteen'),
						"desc" => __('You can upload banner image for your website (optional).', 'twentyfourteen'),
						"id" => "Chelmsford_Market_banner_stalls",
						"type" => "upload");
						
						
						$options[] = array( "name" => __('Add banner image for contact', 'twentyfourteen'),
						"desc" => __('You can upload banner image for your website (optional).', 'twentyfourteen'),
						"id" => "Chelmsford_Market_banner_contact",
						"type" => "upload");
						
						
						$options[] = array( "name" => __('Add banner image for sitemap', 'twentyfourteen'),
						"desc" => __('You can upload banner image for your website  (optional).', 'twentyfourteen'),
						"id" => "Chelmsford_Market_banner_sitemap",
						"type" => "upload");
						
						$options[] = array( "name" => __('map settings', 'twentyfourteen'),
						"type" => "heading");	
						
						$options[] = array( "name" => __('Add map image for map page', 'twentyfourteen'),
						"desc" => __('You can upload custom image for your website map (optional).', 'twentyfourteen'),
						"id" => "Chelmsford_Market_map_image",
						"type" => "upload");
						
						$options[] = array( "name" => __('Add map image for mobile', 'twentyfourteen'),
						"desc" => __('You can upload custom image for your website map (optional).', 'twentyfourteen'),
						"id" => "Chelmsford_Market_mobile_map_image",
						"type" => "upload");

					

				

																
					   
    return $options;
}